## deploy_base
This playbook is used to test my misc. roles that I intend to use as a deployment framework.

### Known issues
The package updates for atomic aren't idempotent.  Some previous ostree transactions register a change, regardless of the actual transactional activity.

Simply comment out the update-packages role in play.yml to avoid this, if desired.

### Example usage
```
[jlay@delta deploy_base]$ ansible-playbook -i hosts play.yml 
username for the user you want to create [jlay]: 
password for created user: 
confirm password for created user: 

PLAY [lan] ************************************************************************************************************************************************

TASK [Gathering Facts] ****************************************************************************************************************************************
ok: [gitlab]

TASK [bootstrap : check if atomic] ****************************************************************************************************************************
ok: [gitlab]

TASK [bootstrap : check for cloud.cfg] ************************************************************************************************************************
ok: [gitlab]

TASK [bootstrap : set fact (atomic state)] ********************************************************************************************************************
ok: [gitlab]

TASK [bootstrap : set fact (cloud.cfg state)] *****************************************************************************************************************
ok: [gitlab]

TASK [bootstrap : install prereqs] ****************************************************************************************************************************
ok: [gitlab] => (item=libselinux-python)
ok: [gitlab] => (item=sudo)

TASK [bootstrap : remove update_etc_hosts from cloud.cfg] *****************************************************************************************************
skipping: [gitlab]

TASK [bootstrap : remove requiretty] **************************************************************************************************************************
ok: [gitlab]

TASK [bootstrap : install epel] *******************************************************************************************************************************
ok: [gitlab]

TASK [update-packages : update packages (atomic)] *************************************************************************************************************
skipping: [gitlab]

TASK [update-packages : update packages (non-atomic)] *********************************************************************************************************
ok: [gitlab]

TASK [update-packages : reboot updated hosts] *****************************************************************************************************************
skipping: [gitlab]

TASK [update-packages : wait for rebooted host to return] *****************************************************************************************************
skipping: [gitlab]

TASK [install-packages : include_tasks] ***********************************************************************************************************************
skipping: [gitlab]

TASK [install-packages : include_tasks] ***********************************************************************************************************************
included: /home/jlay/git/deploy_base/roles/install-packages/tasks/el.yml for gitlab

TASK [install-packages : install packages (RHEL/CentOS/Fedora)] ***********************************************************************************************
ok: [gitlab] => (item=bash-completion)
ok: [gitlab] => (item=htop)
ok: [gitlab] => (item=vim)
ok: [gitlab] => (item=strace)
ok: [gitlab] => (item=dmidecode)
ok: [gitlab] => (item=nethogs)
ok: [gitlab] => (item=sysbench)
ok: [gitlab] => (item=fio)
ok: [gitlab] => (item=rsync)
ok: [gitlab] => (item=iperf3)
ok: [gitlab] => (item=nmap)
ok: [gitlab] => (item=lvm2)
ok: [gitlab] => (item=bind-utils)

TASK [create-user : include_tasks] ****************************************************************************************************************************
skipping: [gitlab]

TASK [create-user : include_tasks] ****************************************************************************************************************************
included: /home/jlay/git/deploy_base/roles/create-user/tasks/el.yml for gitlab

TASK [create-user : creating user jlay in wheel group (RHEL/CentOS/Fedora)] ***********************************************************************************
ok: [gitlab]

TASK [create-user : enable nopasswd sudo (RHEL/CentOS/Fedora)] ************************************************************************************************
ok: [gitlab]

TASK [create-user : copy current pubkeys to ~jlay/.ssh/authorized_keys] ***************************************************************************************
ok: [gitlab] => (item=ssh-ed25519 [...] jlay@workstation)
ok: [gitlab] => (item=ssh-rsa [...] jlay@workstation)

TASK [hardening : disable services] ***************************************************************************************************************************
ok: [gitlab] => (item=postfix)
failed: [gitlab] (item=rpcbind) => {"changed": false, "item": "rpcbind", "msg": "Could not find the requested service rpcbind: host"}
ok: [gitlab] => (item=rsyncd.service)
ok: [gitlab] => (item=rsyncd.socket)
...ignoring

TASK [hardening : disable password auth] **********************************************************************************************************************
ok: [gitlab]

TASK [docker : install docker] ********************************************************************************************************************************
ok: [gitlab]

TASK [docker : add jlay to 'dockerroot' group] ****************************************************************************************************************
ok: [gitlab]

TASK [docker : copy daemon.json] ******************************************************************************************************************************
ok: [gitlab]

TASK [docker : enable/start docker] ***************************************************************************************************************************
ok: [gitlab]

TASK [zfs : install zfs-release package (RHEL/CentOS)] ********************************************************************************************************
ok: [gitlab]

TASK [zfs : install zfs-release package (Fedora)] *************************************************************************************************************
skipping: [gitlab]

TASK [zfs : install zfs and dkms] *****************************************************************************************************************************
ok: [gitlab] => (item=kernel-devel)
ok: [gitlab] => (item=@Development tools)
ok: [gitlab] => (item=dkms)
ok: [gitlab] => (item=zfs)

TASK [zfs : load zfs module] **********************************************************************************************************************************
ok: [gitlab]

TASK [zfs : add zfs to modules-load.d] ************************************************************************************************************************
ok: [gitlab]

TASK [zfs : set zfs_arc_max to 75% installed memory (11630000000 bytes)] **************************************************************************************
ok: [gitlab]

PLAY RECAP ****************************************************************************************************************************************************
gitlab                     : ok=26   changed=0    unreachable=0    failed=0   

[jlay@delta deploy_base]$ 
```

